package com.poststats.rs.api.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Repeatable;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Repeatable(MapConditions.class)
@Target({
		ElementType.FIELD
})
@Retention(RetentionPolicy.RUNTIME)
@Documented
public @interface MapCondition {

	/**
	 * This condition evaluates to true if not set (`null`) or the specified named
	 * `@MapEntry` value evaluates to boolean `true`, numeric non-zero, or any other
	 * not-`null` `Object`. If the specified `@MapEntry` does not exist, it returns
	 * `false`.
	 */
	String mapEntry() default "";

	/**
	 * This condition evaluates to true if not set (`null`) or the specified field
	 * evaluates to boolean `true`, numeric non-zero, or any other not-`null`
	 * `Object`. If the specified field does not exist, an
	 * `IllegalArgumentException` is thrown.
	 */
	String field() default "";

	/**
	 * This condition evaluates to true if not set (`null`) or the specified
	 * no-argument method return value evaluates to boolean `true`, numeric
	 * non-zero, or any other not-`null` `Object`. If the specified no-argument
	 * method does not exist, an `IllegalArgumentException` is thrown.
	 */
	String method() default "";

	/**
	 * This condition evaluates to `true` if not set (`null`) or one of the
	 * specified roles returns `true` in the SecurityContext.isUserInRole(). If
	 * there is no SecurityContext, it returns `false`.
	 */
	String[] rolesAllowed() default {};

}
