package com.poststats.rs.api.model;

import java.util.Collection;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class PagedCollection<T extends Collection<?>> {

	@JsonProperty
	private short page;

	@JsonProperty
	private short perPage;

	@JsonProperty
	private long totalResults;

	@JsonProperty
	private T collection;

	public short getPage() {
		return page;
	}

	public void setPage(short page) {
		this.page = page;
	}

	public short getPerPage() {
		return perPage;
	}

	public void setPerPage(short perPage) {
		this.perPage = perPage;
	}

	public long getTotalResults() {
		return totalResults;
	}

	public void setTotalResults(long totalResults) {
		this.totalResults = totalResults;
	}

	@JsonProperty("collectionResults")
	public int getResults() {
		return this.collection == null ? 0 : this.collection.size();
	}

	@JsonProperty("hasMoreResults")
	public boolean hasMore() {
		return this.totalResults > ((this.page - 1) * this.perPage + this.getResults());
	}

	public T getCollection() {
		return collection;
	}

	public void setCollection(T collection) {
		this.collection = collection;
	}

	public PagedCollection<T> withPage(short page) {
		this.page = page;
		return this;
	}

	public PagedCollection<T> withPerPage(short perPage) {
		this.perPage = perPage;
		return this;
	}

	public PagedCollection<T> withTotalResults(long totalResults) {
		this.totalResults = totalResults;
		return this;
	}

	public PagedCollection<T> withCollection(T collection) {
		this.collection = collection;
		return this;
	}

}
